
Pylint User Manual
==================

Pylint's home page is at http://www.pylint.org and its forge is at
https://bitbucket.org/logilab/pylint

.. toctree::
   :maxdepth: 2

   intro
   run
   output
   message-control
   features
   extensions
   options
   extend
   ide-integration
   plugins
   contribute

   tutorial
   faq
   backlinks
   installation

   changelog



Content wanted
--------------

It would be nice to include in the documentation the following information:

- pylint brain project : what it is, how to install it...

Please send your pull requests via bitbucket if you can help with the above.
